<?php
/*
1.01 Repaired a missing ;
1.02 Replaced some single quotes with double quotes.
1.03 Updated to make editing easier
1.04 Updated to include an OFF mode, added more instructions
1.05 3/4/2010	Geoffrey Walton
	Removed references old price & qty in test output as these were not available.
	Allowed rounding to any no of pence/cents and made it optional.
	Made test output a table.
	Kept the cost price so can be used to update the product if required.
	Prevented selling price falling below cost price.
	Works with admin/local/configure.php file.
	
For Get Price/Quantity Update Feed 1.05 and before, credit is given to the respective authors
----------------------------------------------------------------------------------------

v1.06 10/27/2016  by ecommunlimited
Some of the code had to be updated to work with v2.3.4 BSr. Most of the commenting was done by myself as well

The code has been updated to work with osC v2.3.4 Bootstrap Responsive, Apache, PHP 7 and MYSQL 5.6
This may or may not work with other system configurations

This file can be ran automatically by using a cron job command

Examples of a cron job command

php /home/your-username/public_html/admin/get_feed.php

- OR -

php /home/your-username/public_html/catalog/admin/get_feed.php

If you rename this file, change the above command to reflect the new name.

*/

// Configuration

// Required
// Once the testing has completed and you're sure you're ready to write to your database,
// change the mode of operation from 1 to 0 and save the file
// The 1 or 0 controls whether the data is actually altered in your database or not

$test_mode = 1;     // Test mode = 1  Live mode = 0    

// Required
$working_dir = 'DIR_FS_ADMIN';     // If you have to, change DIR_FS_ADMIN to a valid working directory of your shop otherwise, your server may not let you execute the file
$local_file = 'temp/product_price_counts.csv';     // The $local_file should be changed to the name of the folder/file as you want it stored on your server

// Required
// This is the method you will use to get your data feed from your supplier
// The $get_method can be either http or ftp depending on the access allowed by your supplier and your hosting company
// Note: the get method CAN NOT be https. It has to be http of ftp. This contribution was not designed for https                 
// Valid values are 'http', 'ftp' or 'off'. Off is for if you do not want to execute the file

$get_method = 'http';

// Required										
// The $url_to_file is required if you use the http get method to pull the file from your suppliers server
// Note: It has be a valid URL to pull the updated file from your suppliers CSV file location
// You'll have to change the $url_to_file to the actual URL of your suppliers CSV file location on their server

$url_to_file = 'http://datadownload.xxxxxxxx.com/xxxxxxxx-data/xxxxxxxx-price-counts.csv';

// Required if you use the ftp $get_method to pull the file from your suppliers server  
// Set your ftp user credentials. A lot of times your ftp user credentials are different from your login
// info to your supplier website. Check with them to determine what your ftp user credentials are

$ftp_server = 'ftp.your-dealers-ftp-domain-name.com';     // Change to the suppliers ftp domain name they have provided you with
$ftp_user_name = 'your-dealers-ftp-username';             // Change to the suppliers ftp username they have provided you with
$ftp_user_pass = 'your-dealers-ftp-password';             // Change to the suppliers ftp password they have provided you with
$remote_dir = 'http://datadownload.xxxxxxxx.com/xxxxxxxx-data/xxxxxxxx-price-counts.csv' ;     // Change to the suppliers http domain name, path and file you need to pull
$remote_file = 'xxxxxxxx-price-counts.csv';               // Change to the suppliers products and quantity update file name you need to pull

// Optional
// If you use an MAP, need to markup your prices or end your prices with a certain value, use these
// The $use_map should be set to 0 unless you use it and have the MAP column in the products table of your database

$use_map = 0;     // Set to 1 to enable MAP

// Optional
// The $use_markup should be set to 0 if you DO NOT use a markup
// The $markup should be set to whatever % value you choose
// The $roundto should be set to whatever you want your prices to end with

$use_markup = 0;     // Set to 1 to enable getting the markup percentage from the categories table
$markup = .20;		 // This will be the markup percentage used if a markup is NOT specified in your categories table. Example - .175 is 17.5%
$roundto ='.99';     // The $roundto is what you want your prices to end with. Examples - .99 is 99 cents like $4.99
                     // If you do NOT have a need for your prices to end with a certain value you can leave the $roundto blank such as: $roundto ='';

// Required
// The $type_sep is what separates the values between the columns from the file you pull from your supplier
// Visually look at the file to determine what separates the values
// A comma separated file will have lines that look like this: 1234,127.55,2.3,4567
// A tab delimited file will have lines that look like this: 1234    127.55    2    4567
// Put a comma (,) in between the quotes if it is a comma separated file
// Put (\t) in between the quotes if it is a tab deliminated file
// If by chance you cannot tell the difference just by looking at it, copy the data and save it as .txt and then re-open it to view it
// You'll be able to tell then. Just be sure to re-save the file as .csv

$type_sep = ",";     // use "," for a comma separated file and "\t" for a tab delimited file

// Required
// Setting Column Positions
// The column position is the number of the column from the file you pull from your supplier
// Many files do NOT have numbered columns. Most have headings like SKU, Model, Cost, Price, Quantity, Count, etc
// First you need to determine which columns you're going to use and then count the position of those columns
// Visually look at the file you're pulling and count which position that column is in
// Scenario - Let's say you use the products Model Number as the identifier for your products or to correlate with the products_id in your database.
// And say the products Model Number was in the 1st column of the file. You would then put a 1 in the $model_pos = 1;
// And say the products Quantity was in the 4th column of the file. You would then put a 4 in the $qty_pos = 4;
// And say the products Price was in the 8th column of the file. You would then put a 8 in the $price_pos = 8;
// Don't worry - if the column you need the data from says Cost instead of Price, you can still input that column number in the $price_pos.
// Same goes if the column you need the data from says Count instead of Quantity, You would still input that column number in the $qty_pos.
// Same goes for the $model_pos

$model_pos = 1;     // set the position on the column where the SKU / Model number is
$qty_pos = 4;       // set the position on the column where the Count / Quantity is
$price_pos = 8;     // set the position on the column where the Cost / Price is

// Required
// Defining Your Common Field
// For this to work, the file you pull from your supplier must have a product identifying column that
// matches with the product identifying column from the products table in your database.
// Some shops have created custom fields in their products table like products_sku so they can use the
// SKU as their product identifier. Whether you created a custom field or you use the or products_model
// as your product identifier, it has to be defined. 
// This is how you will define that field. Leave the products_id in place and change products_model to your identifier

define('products_id', 'products_model');     // Default is 'products_model' Change to whatever your common field is

// ///////////////////////////// Do not edit below unless you encounter errors /////////////////////////////

// Shifts the position so starts with 0
$model_pos -= 1;
$qty_pos -= 1;
$price_pos -= 1;

// Starts the download
switch ($get_method) {
case "off":
break;
case "ftp":

// Opens the file to write to
$handle = fopen($local_file, 'w');

// Sets up basic connection
$conn_id = ftp_connect($ftp_server) or die('Unable to connect to database server!');

// FTP login with username and password
$login_result = ftp_login($conn_id, $ftp_user_name, $ftp_user_pass);

// Try to download $remote_file and save it to $handle
if (ftp_fget($conn_id, $handle, $remote_file, FTP_ASCII, 0)) {
 echo "successfully written to $local_file\n";                                // May have to comment this out after testing
} else {
 echo "There was a problem while downloading $remote_file to $local_file\n";  // May have to comment this out after testing
}

// Close the connection and the file handle
ftp_close($conn_id);
fclose($handle);

// End of php-ftp code
break;
case "http":
default:

// Following uses curl as php code
$ch = curl_init($url_to_file);
$fp = fopen($local_file, "w");

curl_setopt($ch, CURLOPT_FILE, $fp);
curl_setopt($ch, CURLOPT_HEADER, 0);

curl_exec($ch);
curl_close($ch);
fclose($fp);
// End of php-curl code
}
// Open database now
// Have to include the configure file
// Set the local configuration parameters
  if (file_exists('includes/local/configure.php')) include('includes/local/configure.php');

  require('includes/configure.php');  
// Include the database functions
  require('includes/functions/database.php');

// This makes the connection to the database
  tep_db_connect($server = DB_SERVER, $username = DB_SERVER_USERNAME, $password = DB_SERVER_PASSWORD, $database = DB_DATABASE) or die('Unable to connect to database server!');

$lines = file($local_file);
// This is the heading of the Test output data
if ($test_mode == true) {
   echo "<table><tr><td>Model </td><td>Cost/MAP </td><td>New Price </td><td>QTY </td><tr>\n";
  }
// Loop through lines in file
foreach ($lines as $line) {

    $items = explode  ($type_sep, $line);
    $model = $items[$model_pos];
    $qty = $items[$qty_pos];
    $cost = $items[$price_pos];
//  $another_field = $items[3];     // Expand if you need to but you will have to add to the sql statement below to get the data into your database.
	if ($use_markup == true) {      // Requires a markup column in the categories table with markeup amount as decimal ( .20 as 20%)
		
// Get and set the markup
	$sql = "select categories.markup from categories,products_to_categories,products where products.products_model = '" . $model . "' and products.products_id = products_to_categories.products_id and products_to_categories.categories_id = categories.categories_id";
	$result = tep_db_query($sql);
	$markupres = mysqli_fetch_row($result);
	$markup = $markupres[0];
}
// Applies the price value to end of your prices. Example - .99 is 99 cents like $4.99
if ($roundto == '') {
	$price = $cost * (1+$markup);
} else {
	$price = (int)($cost * (1+$markup))+ $roundto;
}
// Applies the MAP
if ($use_map == true) {     // Requires a products_map column in the products table, with a value for map, NULL if no MAP
	$sql = "select products_map from products where " . products_id . "= '" . $model . "'";
	$result = tep_db_query($sql);
	$map = mysqli_fetch_row($result);
	
	if (!(is_null($map[0]))) {
		$cost = $map[0];
	}
}
// This is so your markup prices will not go below Cost or MAP
if ($price < $cost) {
	$price = $cost;	
}
// This is the data output of Test mode
if ($test_mode == true) {
   echo "<table border=1>";
   echo " <tr>";
   echo "  <td>" . $model . "</td><td>" . $cost . "</td><td>" . $price . "</td><td>" . $qty . "</td>";
   echo " </tr>";
   echo "</table>"; 
  } else {
// This is the data being input into your database
// It builds and executes the sql statement for the item 
	$sql = "update products set products_quantity = '" . $qty . "', products_price = '" . $price . "' where " . products_id . "= '" . $model . "'";
	$result = tep_db_query($sql);      // This executes the sql
  }
 } 
// Closes the database connection
tep_db_close();

?>